@@ -1,6 +1,6 @@
 """Module to hold the constans of the SDK."""
 
-API_BASE_URL = "https://sandbox.getplutto.com/api"
+API_BASE_URL = "https://app.getplutto.com/api"
 API_VERSION = "v1"
 GENERAL_DOC_URL = "https://docs.getplutto.com/"
 LINK_HEADER_PATTERN = r'<(?P<url>.*)>;\s*rel="(?P<rel>.*)"'
